You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jb...@apache.org on 2006/10/19 16:11:11 UTC

svn commit: r465637 - /incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java

Author: jboynes
Date: Thu Oct 19 07:11:11 2006
New Revision: 465637

URL: http://svn.apache.org/viewvc?view=rev&rev=465637
Log:
apply patch from Jojo Joseph for TUSCANY-773

Modified:
    incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java

Modified: incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java?view=diff&rev=465637&r1=465636&r2=465637
==============================================================================
--- incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java (original)
+++ incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java Thu Oct 19 07:11:11 2006
@@ -57,7 +57,8 @@
  * <ul>
  *   <li>Adds the boot dependencies transitively to WEB-INF/tuscany/boot</li>
  *   <li>By default boot libraries are transitively resolved from webapp-host</li>
  *   <li>This can be overridden using the configuration/bootLibs element in the plugin</li>
  *   <li>Adds the extension artifacts specified using configuration/extensions to WEB-INF/tuscany/extensions</li>
  *   <li>If configuration/loadExtensionsDependency is set to true extension dependencies are transitivel loaded</li>
  *   <li>Extension dependencies are loaded into WEB-INF/tuscany/repository directory in a Maven repo format</li>
@@ -179,6 +180,13 @@
     private boolean loadExtensionDependencies;
 
     /**
+     * The default version of boot dependany jar files
+     * 
+     * @parameter
+     */
+    private String runTimeVersion = null;
+    
+    /**
      * WEB-INF jar files.
      */
     private Set<String> packagedLibs = new HashSet<String>();
@@ -202,6 +210,14 @@
 
         try {
 
+        	// if there is a runtime version specified and no bootLib dependancies,
+        	// modify the bootLibs to have the runtime version.
+        	if (runTimeVersion != null && bootLibs == Dependency.getDefaultBootLibs()) {
+        		Dependency dependancy = new Dependency("org.apache.tuscany.sca.runtime", 
+        				"webapp-host", runTimeVersion);
+        		bootLibs = new Dependency[] {dependancy};
+        	}
+        	
             originalWarFile = new File(outputDirectory, warName + ".war");
             originalWar = new JarFile(originalWarFile);
 



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org


Re: Apply to M2? Re: svn commit: r465637

Posted by Rick <cr...@gmail.com>.
Sounds ok.
  I'll assume at this point, for M2 we should be doing a little more than just 
seeing things compile and unit tc's are ok when we make changes?  Try running 
some samples that we think may be affected by the change and verify all is well?

Jeremy Boynes wrote:
> I applied a patch from Jojo that allows you to specify the version of 
> the bootlibs that the plugin will use, overriding the default.
> 
> This seems small and stable and I think we should apply to M2 as well.
> -- 
> Jeremy
> 
> On Oct 19, 2006, at 7:11 AM, jboynes@apache.org wrote:
> 
>> Author: jboynes
>> Date: Thu Oct 19 07:11:11 2006
>> New Revision: 465637
>>
>> URL: http://svn.apache.org/viewvc?view=rev&rev=465637
>> Log:
>> apply patch from Jojo Joseph for TUSCANY-773
>>
>> Modified:
>>     
>> incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java 
>>
>>
>> Modified: 
>> incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java 
>>
>> URL: 
>> http://svn.apache.org/viewvc/incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java?view=diff&rev=465637&r1=465636&r2=465637 
>>
>> ============================================================================== 
>>
>> --- 
>> incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java 
>> (original)
>> +++ 
>> incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java 
>> Thu Oct 19 07:11:11 2006
>> @@ -57,7 +57,8 @@
>>   * <ul>
>>   *   <li>Adds the boot dependencies transitively to 
>> WEB-INF/tuscany/boot</li>
>>   *   <li>By default boot libraries are transitively resolved from 
>> webapp-host</li>
>> - *   <li>This can be overridden using the configuration/bootLibs 
>> element in the plugin</li>
>> + *   <li>The version of boot libraries can be specified using 
>> configuration/runTimeVersion element</li>
>> + *   <li>Boot libraries can be overridden using the 
>> configuration/bootLibs element in the plugin</li>
>>   *   <li>Adds the extension artifacts specified using 
>> configuration/extensions to WEB-INF/tuscany/extensions</li>
>>   *   <li>If configuration/loadExtensionsDependency is set to true 
>> extension dependencies are transitivel loaded</li>
>>   *   <li>Extension dependencies are loaded into 
>> WEB-INF/tuscany/repository directory in a Maven repo format</li>
>> @@ -179,6 +180,13 @@
>>      private boolean loadExtensionDependencies;
>>
>>      /**
>> +     * The default version of boot dependany jar files
>> +     *
>> +     * @parameter
>> +     */
>> +    private String runTimeVersion = null;
>> +
>> +    /**
>>       * WEB-INF jar files.
>>       */
>>      private Set<String> packagedLibs = new HashSet<String>();
>> @@ -202,6 +210,14 @@
>>
>>          try {
>>
>> +            // if there is a runtime version specified and no bootLib 
>> dependancies,
>> +            // modify the bootLibs to have the runtime version.
>> +            if (runTimeVersion != null && bootLibs == 
>> Dependency.getDefaultBootLibs()) {
>> +                Dependency dependancy = new 
>> Dependency("org.apache.tuscany.sca.runtime",
>> +                        "webapp-host", runTimeVersion);
>> +                bootLibs = new Dependency[] {dependancy};
>> +            }
>> +           
>>              originalWarFile = new File(outputDirectory, warName + 
>> ".war");
>>              originalWar = new JarFile(originalWarFile);
>>
>>
>>
>>
>> ---------------------------------------------------------------------
>> To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
>> For additional commands, e-mail: tuscany-commits-help@ws.apache.org
>>
> 
> 
> ---------------------------------------------------------------------
> To unsubscribe, e-mail: tuscany-dev-unsubscribe@ws.apache.org
> For additional commands, e-mail: tuscany-dev-help@ws.apache.org
> 
> 

---------------------------------------------------------------------
@@ -57,7 +57,8 @@
  *   <li>Adds the boot dependencies transitively to WEB-INF/tuscany/boot</li>
  *   <li>By default boot libraries are transitively resolved from webapp-host</li>
- *   <li>This can be overridden using the configuration/bootLibs element in the plugin</li>
+ *   <li>The version of boot libraries can be specified using configuration/runTimeVersion element</li>
+ *   <li>Boot libraries can be overridden using the configuration/bootLibs element in the plugin</li>
  *   <li>Adds the extension artifacts specified using configuration/extensions to WEB-INF/tuscany/extensions</li>
  *   <li>If configuration/loadExtensionsDependency is set to true extension dependencies are transitivel loaded</li>
To unsubscribe, e-mail: tuscany-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-dev-help@ws.apache.org


Apply to M2? Re: svn commit: r465637

Posted by Jeremy Boynes <jb...@apache.org>.
I applied a patch from Jojo that allows you to specify the version of  
the bootlibs that the plugin will use, overriding the default.

This seems small and stable and I think we should apply to M2 as well.
--
Jeremy

On Oct 19, 2006, at 7:11 AM, jboynes@apache.org wrote:

> Author: jboynes
> Date: Thu Oct 19 07:11:11 2006
> New Revision: 465637
>
> URL: http://svn.apache.org/viewvc?view=rev&rev=465637
> Log:
> apply patch from Jojo Joseph for TUSCANY-773
>
> Modified:
>     incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/ 
> apache/tuscany/plugin/war/TuscanyWarMojo.java
>
> Modified: incubator/tuscany/java/sca/plugins/plugin.war/src/main/ 
> java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java
> URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sca/ 
> plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/ 
> TuscanyWarMojo.java?view=diff&rev=465637&r1=465636&r2=465637
> ====================================================================== 
> ========
> --- incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/ 
> apache/tuscany/plugin/war/TuscanyWarMojo.java (original)
> +++ incubator/tuscany/java/sca/plugins/plugin.war/src/main/java/org/ 
> apache/tuscany/plugin/war/TuscanyWarMojo.java Thu Oct 19 07:11:11 2006
> @@ -57,7 +57,8 @@
>   * <ul>
>   *   <li>Adds the boot dependencies transitively to WEB-INF/ 
> tuscany/boot</li>
>   *   <li>By default boot libraries are transitively resolved from  
> webapp-host</li>
> - *   <li>This can be overridden using the configuration/bootLibs  
> element in the plugin</li>
> + *   <li>The version of boot libraries can be specified using  
> configuration/runTimeVersion element</li>
> + *   <li>Boot libraries can be overridden using the configuration/ 
> bootLibs element in the plugin</li>
>   *   <li>Adds the extension artifacts specified using  
> configuration/extensions to WEB-INF/tuscany/extensions</li>
>   *   <li>If configuration/loadExtensionsDependency is set to true  
> extension dependencies are transitivel loaded</li>
>   *   <li>Extension dependencies are loaded into WEB-INF/tuscany/ 
> repository directory in a Maven repo format</li>
> @@ -179,6 +180,13 @@
>      private boolean loadExtensionDependencies;
>
>      /**
> +     * The default version of boot dependany jar files
> +     *
> +     * @parameter
> +     */
> +    private String runTimeVersion = null;
> +
> +    /**
>       * WEB-INF jar files.
>       */
>      private Set<String> packagedLibs = new HashSet<String>();
> @@ -202,6 +210,14 @@
>
>          try {
>
> +        	// if there is a runtime version specified and no bootLib  
> dependancies,
> +        	// modify the bootLibs to have the runtime version.
> +        	if (runTimeVersion != null && bootLibs ==  
> Dependency.getDefaultBootLibs()) {
> +        		Dependency dependancy = new Dependency 
> ("org.apache.tuscany.sca.runtime",
> +        				"webapp-host", runTimeVersion);
> +        		bootLibs = new Dependency[] {dependancy};
> +        	}
> +        	
>              originalWarFile = new File(outputDirectory, warName +  
> ".war");
>              originalWar = new JarFile(originalWarFile);
>
>
>
>
> ---------------------------------------------------------------------
> To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
> For additional commands, e-mail: tuscany-commits-help@ws.apache.org
>


---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-dev-help@ws.apache.org